! =================================================================================================================================
! MODULE       : stomate_prescribe
!
! CONTACT      : orchidee-help _at_ ipsl.jussieu.fr
!
! LICENCE      : IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!
!>\BRIEF         Initialize and update density, height, basal area and crown area.
!!
!!\n DESCRIPTION: None
!!
!! RECENT CHANGE(S): None
!!
!! REFERENCE(S)	:
!!
!! SVN          :
!! $HeadURL$
!! $Date$
!! $Revision$
!! \n
!_ ================================================================================================================================

MODULE stomate_prescribe

  ! modules used:

  USE ioipsl_para
  USE stomate_data
  USE pft_parameters
  USE constantes
  USE function_library,    ONLY: calculate_c0_alloc, cc_to_lai, & 
       cc_to_biomass, check_surface_area, check_mass_balance, &
       wood_to_qmdia, Nmax, sort_circ_class_biomass

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC prescribe, make_saplings, prescribe_clear

  ! first call
  LOGICAL, SAVE             :: firstcall_prescribe = .TRUE.
!$OMP THREADPRIVATE(firstcall_prescribe)

CONTAINS

! =================================================================================================================================
!! SUBROUTINE   : prescribe_clear
!!
!>\BRIEF        : Set the firstcall_prescribe flag back to .TRUE. to prepare for the next simulation.
!_=================================================================================================================================

  SUBROUTINE prescribe_clear
    firstcall_prescribe=.TRUE.
  END SUBROUTINE prescribe_clear


!! ================================================================================================================================
!! SUBROUTINE   : prescribe
!!
!>\BRIEF         Works only with static vegetation and agricultural PFTs.
!!               Initialize biomass, density, presence in the first call
!!               and update them in the following.
!!
!! DESCRIPTION (functional, design, flags): \n
!! This module works only with static vegetation and agricultural PFTs.
!! In the first call, initialize density of individuals, biomass,
!! and leaf age distribution to some reasonable value. In the following calls,
!! these variables are updated following a stand replacing disturbance or
!! if the conditions are suitable for recruitment. 
!!
!! To fulfill these purposes, pipe model are used:
!! \latexonly 
!!     \input{prescribe1.tex}
!!     \input{prescribe2.tex}
!! \endlatexonly
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLES(S): ::ind, ::biomass
!!
!! REFERENCES   :
!! - Krinner, G., N. Viovy, et al. (2005). "A dynamic global vegetation model 
!!   for studies of the coupled atmosphere-biosphere system." Global 
!!   Biogeochemical Cycles 19: GB1015, doi:1010.1029/2003GB002199.
!! - Sitch, S., B. Smith, et al. (2003), Evaluation of ecosystem dynamics,
!!   plant geography and terrestrial carbon cycling in the LPJ dynamic 
!!   global vegetation model, Global Change Biology, 9, 161-185.
!! - McDowell, N., Barnard, H., Bond, B.J., Hinckley, T., Hubbard, R.M., Ishii, 
!!   H., Köstner, B., Magnani, F. Marshall, J.D., Meinzer, F.C., Phillips, N., 
!!   Ryan, M.G., Whitehead D. 2002. The relationship between tree height and leaf 
!!   area: sapwood area ratio. Oecologia, 132:12–20.
!! - Novick, K., Oren, R., Stoy, P., Juang, F.-Y., Siqueira, M., Katul, G. 2009. 
!!   The relationship between reference canopy conductance and simplified hydraulic 
!!   architecture. Advances in water resources 32, 809-819.
!! - Ruger et al. 2009, J. of Ecol. doi: 10.1111/j.1365-2745.2009.01552.x  
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

SUBROUTINE prescribe (npts, veget_cov_max, dt, PFTpresent, &
       everywhere, when_growthinit, leaf_frac, circ_class_dist, &
       circ_class_n, circ_class_biomass, atm_to_bm, &
       forest_managed, KF, plant_status, age, npp_longterm, &
       lm_lastyearmax, tau_eff_leaf, tau_eff_sap, tau_eff_root, &
       k_latosa_adapt, light_tran_to_level_season, &
       EndOfYear, lpft_replant,species_change_map)

  !! 0. Parameters and variables declaration

  !! 0.1 Input variables

    INTEGER(i_std), INTENT(in)                        :: npts               !! Domain size (unitless)
    INTEGER(i_std), DIMENSION (:,:), INTENT(in)       :: forest_managed     !! forest management flag
    REAL(r_std), INTENT(in)                           :: dt                 !! time step (dt_days)   
    REAL(r_std), DIMENSION(:,:), INTENT(in)           :: veget_cov_max          !! "maximal" coverage fraction of a PFT 
                                                                            !! (LAI -> infinity) on ground. May sum to
                                                                            !! less than unity if the pixel has
                                                                            !! nobio area. (unitless; 0-1)
    REAL(r_std), DIMENSION(:,:), INTENT(in)           :: tau_eff_root       !! Effective root turnover time that accounts
                                                                            !! waterstress (days)
    REAL(r_std), DIMENSION(:,:), INTENT(in)           :: tau_eff_sap        !! Effective sapwood turnover time that accounts
                                                                            !! waterstress (days)
    REAL(r_std), DIMENSION(:,:), INTENT(in)           :: tau_eff_leaf       !! Effective leaf turnover time that accounts
                                                                            !! waterstress (days)
    LOGICAL, DIMENSION(:,:), OPTIONAL, INTENT(in)     :: lpft_replant       !! Set to true if a PFT has been clearcut
                                                                            !! and needs to be replaced by another species
    INTEGER(i_std), DIMENSION (:,:), INTENT(in)       :: species_change_map !! map which gives the PFT number that each PFT
    REAL(r_std), DIMENSION (:,:,:), INTENT(in)        :: light_tran_to_level_season !! Seasonal fraction of light transmitted to canopy levels
    LOGICAL, INTENT(in)                               :: EndOfYear          !! Flag set on the last day of the year used 
                                                                            !! to update "yearly variables". This 
                                                                            !! variable must be .TRUE. once a year
    REAL(r_std), DIMENSION(:), INTENT(in)             :: circ_class_dist    !! The probability distribution of trees 
                                                                            !! in a circ class in case of a 
                                                                            !! redistribution (unitless).

  !! 0.2 Output variables


  !! 0.3 Modified variables

    LOGICAL, DIMENSION(:,:), INTENT(inout)            :: PFTpresent         !! PFT present (0 or 1)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: plant_status       !! Growth and phenological status of the plant
                                                                            !! Different stati are listed in in constantes_var
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: everywhere         !! is the PFT everywhere in the grid box or 
                                                                            !! very localized (after its introduction) (?)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: when_growthinit    !! how many days ago was the beginning of 
                                                                            !! the growing season (days)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: npp_longterm       !! "long term" net primary productivity
                                                                            !! @tex ($gC m^{-2} year^{-1}$) @endtex
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: age                !! mean age (years)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: lm_lastyearmax     !! last year's maximum leaf mass for each PFT 
                                                                            !! @tex ($gC m^{-2}$) @endtex
    REAL(r_std), DIMENSION(:,:,:), INTENT(inout)      :: circ_class_n       !! Number of individuals in each circ class
                                                                            !! @tex $(ind m^{-2})$ @endtex
    REAL(r_std), DIMENSION(:,:,:,:,:), INTENT(inout)  :: circ_class_biomass !! Biomass components of the model tree  
                                                                            !! within a circumference class
                                                                            !! class @tex $(g C ind^{-1})$ @endtex
    REAL(r_std), DIMENSION(:,:,:), INTENT(inout)      :: atm_to_bm          !! CO2 or N taken from the atmosphere to get
                                                                            !! the seed C and N
                                                                            !! to create the seedlings 
                                                                            !!  @tex (gC.m^{-2}dt^{-1})$ @endtex  
    REAL(r_std), DIMENSION(:,:,:), INTENT(inout)      :: leaf_frac          !! fraction of leaves in leaf age 
                                                                            !! class (unitless;0-1)
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: KF                 !! Scaling factor to convert sapwood mass
                                                                            !! into leaf mass (m) - this variable is 
                                                                            !! passed to other routines
    REAL(r_std), DIMENSION(:,:), INTENT(inout)        :: k_latosa_adapt     !! Leaf to sapwood area adapted for long 
                                                                            !! term water stress (m)


  !! 0.4 Local variables
    REAL(r_std), DIMENSION(nvm)                       :: c0_alloc           !! Root to sapwood tradeoff parameter
    INTEGER(i_std)                                    :: ipts, ivm          !! index (unitless)
    INTEGER(i_std)                                    :: ipar, ilev         !! index (unitless)
    INTEGER(i_std)                                    :: icir, iele, imbc   !! index (unitless)
    INTEGER(i_std)                                    :: deb,fin, imaxt     !! index (unitless)
    REAL(r_std), DIMENSION(npts,nvm)                  :: k_latosa           !! Height dependent base value to calculate 
                                                                            !! KF (-) 
    REAL(r_std), DIMENSION(nvm,ncirc,nparts,nelements):: bm_sapl            !! Sapling biomass for the functional
                                                                            !! allocation with a dimension for the 
                                                                            !! circumference classes
                                                                            !! @tex $(gC.ind^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm)                  :: LF                 !! Scaling factor to convert sapwood mass
                                                                            !! into root mass (unitless)
    REAL(r_std), DIMENSION(npts,nvm)                  :: lstress_fac        !! Light stress factor, based on total
                                                                            !! transmitted light (unitless, 0-1)
    REAL(r_std), DIMENSION(npts,nvm,ncirc)            :: circ_class         !! circumference of individual trees
    REAL(r_std), DIMENSION(nparts)                    :: bm_init            !! Biomass needed to initiate the next 
                                                                            !! planting @tex $(gC m^{-2})$ @endtex 
    REAL(r_std), DIMENSION(ncirc)                     :: nb_trees_i         !! Number of trees in each twentith 
                                                                            !! circumference quantile of the 
                                                                            !! distribution (ind) 
    REAL(r_std)                                       :: excedent           !! Number of trees after truncation to be 
                                                                            !! reallocated to smaller quantiles of the 
                                                                            !! distribution (ind) 
    REAL(r_std)                                       :: max_circ_init      !! Maximum initial circumferences of the 
                                                                            !! truncated exponential distribution (cm) 
    REAL(r_std), DIMENSION(ncirc)                     :: ave_tree_height    !! The height of the ideal tree in each
                                                                            !! circumference class of the 
                                                                            !! distribution (ind)...not saved since
                                                                            !! it should only be used for prescribing
    REAL(r_std), DIMENSION(npts,nvm,nmbcomp,nelements):: check_intern       !! Contains the components of the internal
                                                                            !! mass balance chech for this routine
                                                                            !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nelements)        :: closure_intern     !! Check closure of internal mass balance
                                                                            !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nelements)        :: pool_start         !! Start and end pool of this routine 
                                                                            !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nelements)        :: pool_end           !! Start and end pool of this routine 
                                                                            !! @tex $(gC pixel^{-1} dt^{-1})$ @endtex
    REAL(r_std)                                       :: delta_KF           !! Difference between new and old estimate 
                                                                            !! of KF while iterating
    REAL(r_std), DIMENSION(npts,nvm)                  :: veget_cov_max_begin    !! temporary storage of veget_cov_max to check area conservation    
    REAL(r_std)                                       :: sapwood_density    !! Sapwood density gC m^{-3}
    REAL(r_std)                                       :: dia_init           !! Diameter of a sapling (m)
    REAL(r_std)                                       :: qmd_init           !! Quadratic mean diameter of the initial stand of seedlings (m)
    REAL(r_std)                                       :: ind_init           !! Maximum number of individuals when establishing a new forest (#/m^{-2})     
    REAL(r_std)                                       :: wood_init          !! Wood mass of a sapling (g C tree^{-1})                    
    INTEGER(i_std)                                    :: iloop              !! Index
    LOGICAL                                           :: establish          !! Logical flag to establish a new young vegetation
                                                                            !! after a stand replacing disturbance 
    LOGICAL                                           :: recruite           !! Logical flag to add saplings of a PFT under an
                                                                            !! existing canopy of the same PFT 
    REAL(r_std), DIMENSION(npts,nvm,ncirc)            :: old_circ_class_n   !! Old number of individuals in each circ class
                                                                            !! @tex $(ind m^{-2})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,ncirc,nparts,nelements) &
                                                      :: old_circ_class_biomass !! Old biomass components of the model tree  
                                                                            !! within a circumference class
                                                                            !! class @tex $(g C ind^{-1})$ @endtex
    REAL(r_std), DIMENSION(npts,nvm,nparts,nelements)  :: old_biomass       !! Old stand level biomass 
                                                                            !! tex $(gC.m^{-2})$ @endtex
    REAL(r_std), DIMENSION(ncirc)                      :: height_small      !! Height of the smallest tree in circ_class_biomass
                                                                            !! tex $(m)$ @endtex
    REAL(r_std)                                        :: dia_small         !! Diameter of the smallest tree in circ_class_biomass
                                                                            !! tex $(m)$ @endtex   
    REAL(r_std)                                        :: height_sapl       !! Height of the recruitment sapling
                                                                            !! tex $(m)$ @endtex                                                           
    REAL(r_std)                                        :: new_ind           !! density of new individuals 
    REAL(r_std)                                        :: old_ind           !! density of old individuals                                        
    REAL(r_std)                                        :: cn_leaf,cn_root   !! CN ratio of leaves, and roots
                                                                            !! (gC/gN)
    REAL(r_std)                                        :: cn_wood           !! CN ratio of wood pool
                                                                            !! (gC/gN)
    REAL(r_std)                                        :: coeff 
    REAL(r_std), DIMENSION(ncirc)                      :: dummy
   
    REAL(r_std)                                        :: lambda            !! lambda of the truncated exponential
                                                                            !! distribution of initial diameters (1/cm**2)
    REAL(r_std)                                        :: tmp_ind           !! temporary number of individuals per m-2
    REAL(r_std), DIMENSION(ncirc)                      :: circ_class_n_new  !! variable used to sort circ_class_n
    REAL(r_std), DIMENSION(ncirc,nparts,nelements)     :: circ_class_biomass_new !! variable used to sort circ_class_biomass
 
!_ ================================================================================================================================

    IF (printlev>=2) WRITE(numout,*) 'Entering stomate_prescribe.f90'

  !! 1. Initialize biomass at first call

    !! 1.1 Initialize local printlev
    !printlev_loc=get_printlev('prescribe')

    !! 1.2 Store for closing the mass balance with recruitment   
    old_biomass(:,:,:,:)= cc_to_biomass(npts,nvm,&
         circ_class_biomass(:,:,:,:,:), & 
         circ_class_n(:,:,:))
       
    
    !! 1.3 Initialize check for mass balance closure 
    IF (err_act.GT.1) THEN

       check_intern(:,:,:,:) = zero
       pool_start(:,:,:) = zero
       DO iele = 1,nelements

          ! atm_to_bm has as intent inout, the variable 
          ! accumulates carbon over the course of a day. 
          ! Use the difference between start and the end of 
          ! this routine
          check_intern(:,:,iatm2land,iele) = - un * &
               atm_to_bm(:,:,iele) * veget_cov_max(:,:) * dt

          DO ipar = 1,nparts
          
             DO icir = 1,ncirc

                ! Initial biomass pool. Use circ_class_biomass
                ! because that variable is the prognostic variable
                ! biomass is syncronized to circ_class_biomass. If 
                ! many diameter classes are used, each diameter class
                ! separatly passes all criteria but when combined
                ! a mass balance problem occurs.
                pool_start(:,:,iele) = pool_start(:,:,iele) + &
                   circ_class_biomass(:,:,icir,ipar,iele) * &
                   circ_class_n(:,:,icir) * veget_cov_max(:,:)

             ENDDO
             
          ENDDO

       ENDDO

       !! 1.3 Initialize check for area conservation
       veget_cov_max_begin(:,:) = veget_cov_max(:,:)

    ENDIF ! err_act.GT.1

  !! 2. Prescribe carbon and nitrogen biomass

    ! We want the vegetation to regrow after a stand replacing disturbance
    ! So loop over every point and PFT.  If there is supposed to be 
    ! vegetation here (according to veget_cov_max) but there isn't (according 
    ! to ind), then establish a new young vegetation in that PFT.
    DO ivm = 2,nvm ! Loop over PFTs

       DO ipts = 1, npts ! Loop over pixels

          !! 2.1 Wait for the end of the year to replant
          !  If we are regrowing different species after managed forests
          !  are killed/die, we sometimes need to prevent them regrowing.
          !  This is only true if they die in the middle of the year due 
          !  to natural causes, in which case they will be replanted at 
          !  the end of the year. This loop checks to see if we regrow 
          !  this PFT now or later. We can regrow a PFT after lpft_replant 
          !  is set back to false so before that we need to process all the 
          !  information such that the correct species will be regrown. 
          !  lpft_replant is an optional variable. First test whether it is 
          !  present.
          IF(ok_change_species)THEN
             IF(PRESENT(lpft_replant))THEN
                IF(lpft_replant(ipts,ivm))THEN
                    ! .AND. agec_group(ivm)/=species_change_map(ipts,ivm))THEN
                    CYCLE
                ENDIF
             ENDIF
          ENDIF

          ! Debug
          IF(printlev_loc.GT.4)THEN
             WRITE(numout,*) 'PFT ',ivm
             WRITE(numout,*) 'plant_status ', plant_status(ipts,ivm)
             WRITE(numout,*) 'veget_cov_max ', veget_cov_max(ipts,ivm)
             WRITE(numout,*) 'recruitment_pft ',recruitment_pft(ivm)
             WRITE(numout,*) 'ok_dgvm ',  ok_dgvm
             WRITE(numout,*) 'ok_recruitment ',ok_recruitment
             WRITE(numout,*) 'biomass - C, ', &
                  SUM(SUM(circ_class_biomass(ipts,ivm,:,:,icarbon),1))
             WRITE(numout,*) 'biomass - N, ', &
                  SUM(SUM(circ_class_biomass(ipts,ivm,:,:,initrogen),1))
             WRITE(numout,*) 'EndOfYear ', EndOfYear
          ENDIF
          !

          ! Decide whether we have to establish new vegetation (::establish)
          ! allow recruitment (::recruite). These two local variables were
          ! introduced to allow maximal flexibility so within a single
          ! run, PFTs with and without recruitment can co-exist.         
          IF( ( (plant_status(ipts,ivm) .EQ. iprescribe) .OR. & 
               (plant_status(ipts,ivm) .EQ. idead) ) .AND. &
               (SUM(SUM(circ_class_biomass(ipts,ivm,:,:,icarbon),1)) .LE. min_stomate) .AND. &
               (veget_cov_max(ipts,ivm) .GT. min_stomate) .AND. &
               (.NOT. ok_dgvm) ) THEN

             ! The vegetation just died from replacing disturbances
             ! (two first conditions). The new vegetation could be 
             ! of the same or a different PFT than the previous 
             ! vegetation. 
             establish = .TRUE.
             recruite = .FALSE.

             ! Debug
             IF (printlev_loc>=4) THEN
                WRITE(numout,*) 'We are calling stomate_prescribe.f90 &
                     & to initialize PFT  ',ivm
             ENDIF
             !-

          ELSEIF( ( (plant_status(ipts,ivm) .NE. iprescribe) .OR. & 
               (plant_status(ipts,ivm) .NE. idead) ) .AND. &
               (SUM(SUM(circ_class_biomass(ipts,ivm,:,:,icarbon),1)) .GT. min_stomate) .AND. &
               (veget_cov_max(ipts,ivm) .GT. min_stomate) .AND. &
               (recruitment_pft(ivm)) .AND. &
               (.NOT. ok_dgvm) .AND. &
               (ok_recruitment) .AND. &
               (EndOfYear) ) THEN

             ! There is already vegetation (first three conditions)
             ! and this specific PFT has recruitment (condition 5)
             ! Only use recruitment when the recruitment flag is TRUE
             ! (condition 7)
             establish = .FALSE.
             recruite = .TRUE.

             ! Debug
             IF (printlev_loc>=4) THEN
                WRITE(numout,*) 'We are calling stomate_prescribe.f90 &
                     & for sapling recruitment in PFT  ',ivm
             ENDIF
             !-
             
          ELSEIF( (veget_cov_max(ipts,ivm).LT. min_stomate) .AND. &
             (SUM(SUM(circ_class_biomass(ipts,ivm,:,:,icarbon),1)) .LT. min_stomate) .AND. &
             (SUM(circ_class_n(ipts,ivm,:)) .LT. min_stomate) )THEN

             ! The PFT is not defined. Initialize the variables
             ! to ensure that all goes well when moving and merging 
             ! different age classes.
             circ_class_n(ipts,ivm,:) = zero
             circ_class_biomass(ipts,ivm,:,:,icarbon) = zero 

             ! Conditions are not fullfilled for establishing
             ! new vegetation
             establish = .FALSE.
             recruite = .FALSE.

          ELSEIF (veget_cov_max(ipts,ivm) .GT. min_stomate) THEN

             ! Conditions are not fullfilled for either establishing 
             ! a new young vegetation or having recruitment under an
             ! exisisting vegetation of the same PFT.
             establish = .FALSE.
             recruite = .FALSE.

             ! Debug
             IF (printlev_loc>=4) THEN
                WRITE(numout,*) 'We are calling stomate_prescribe.f90 &
                     & but nothing should be done for PFT ',ivm
             ENDIF
             

          ELSE

             ! Unexpected condition
             CALL ipslerr_p (3,'stomate_prescribe.f90',&
                  'Unexpected condition - time to rethink the', &
                  'IF that choses between establish and recruite','')

          ENDIF

          !! 2.2 Calculate variables that will determine the size of the saplings
          IF( establish .OR. recruite )THEN

             !! 2.2.1 Calculate c0_alloc
             ! The calculation starts with c0_alloc, it only depends on PFT and 
             ! the effective longiveties.
             c0_alloc(ivm) = calculate_c0_alloc(ipts, ivm, &
                  tau_eff_root(ipts,ivm),tau_eff_sap(ipts,ivm))
             
             !! 2.2.2 Calculate k_latosa for newly established PFTs
             !  If a new vegetation has to be established we recalculate
             !  k_latosa from the parameter file (see note on physiological
             !  memory of k_latosa below). If we add recruits we use the KF of
             !  the existing vegetation.
             IF (establish) THEN

                ! Initialize tree level variables
                circ_class_n(ipts,ivm,:) = zero
                circ_class_biomass(ipts,ivm,:,:,:) = zero

                ! Assume that there is no physiological memory for k_latosa
                ! between different generations (this is probably true when
                ! trees are planted but seems less likely for natural
                ! regeneration. The first test that implemented memory has
                ! caused problems with the LAI from the second generation
                ! onwards. Nevertheless, we still use k_latosa_adapt. In case
                ! someone want to try again in the future, the structure of
                ! the code is ready to account for memory
                k_latosa_adapt(ipts,ivm) = k_latosa_min(ivm)

                ! Debugging
                IF (printlev_loc>=4) THEN
                   WRITE(numout,*) 'Establish a PFT (stomate_prescribe.f90):'
                   WRITE(numout,*) ' Imposing initial biomass for prescribed &
                        & trees, initial reserve mass for prescribed grasses.'
                   WRITE(numout,*) ' Declaring prescribed PFTs present.'
                   WRITE(numout,*) ' Grid point: ',ipts,' PFT Type: ',ivm
                   WRITE(numout,*) ' Establish ',establish,' Recruite ',recruite 
                ENDIF
                !-
                
             ENDIF ! establish

             !! 2.2.3 Calculate Lightstress
             !  Note that light and water stress have an opposite effect on KF. 
             !  Waterstress will decrease KF because more C should be allocated 
             !  to the roots. Light stress will increase KF because more C should 
             !  be allocated to the leaves.
             !  Lightstress varies from 0 to 1 and is calculated from the canopy 
             !  structure (veget).
             IF (establish) THEN

                ! Given that there is no vegetation at this point, the
                ! lightstress cannot be calculated and is set to 1.
                ! However, as soon as we grow a canopy it will experience
                ! light stress and so KF should be adjusted.
                lstress_fac(ipts,ivm) = un

             ELSEIF (recruite) THEN 

                ! We already have vegetation, so we should do recruitment if 
                ! we want it for this PFT. First lets compute light stress based 
                ! on the fraction of light reaching the ground (level 1),
                ! averaged over all daytime time steps (sinang>0) of the vegetative 
                ! period (gpp>0). This is based on Pgap and accounts for canopy
                ! structure. 
                lstress_fac(ipts,ivm)=light_tran_to_level_season(ipts,ivm,1)

                ! Debug
                IF(printlev_loc>=4)THEN
                   WRITE(numout,*) 'Mean seasonal transmitted light used in &
                        & stomate_prescribe.f90 ' // & 
                        & '(ivm,ipts,nlevels_tot) ',ivm,ipts,nlevels_tot
                   DO ilev = nlevels_tot,1,-1
                      WRITE(numout,*) ilev,light_tran_to_level_season(ipts,ivm,ilev)
                   ENDDO
                   WRITE(numout,*) 'lstress_fac from CN-CAN is ', &
                        lstress_fac(ipts,ivm)*100, ' (%)'
                ENDIF
                !-

             ENDIF ! establish/recruite for light

          ENDIF ! establish .OR. recruite for initialization
          
          !! 2.3 Initial vegetation has to be prescribed only when the vegetation is 
          ! static
          IF (establish .OR. recruite) THEN

             !! 2.3.1 Initialize woody PFT's 
             !  Use veget_cov_max to check whether the PFT is present. If the PFT 
             !  is present but it has no biomass, prescribe its biomass (gC m-{2}).
             IF ( is_tree(ivm) ) THEN

                ! prescribe/recruitment branching for actual process
                IF (establish) THEN

                   IF (ncirc .EQ. 1) THEN
                   
                      ! Calculate the height range based on the prescribed 
                      ! min/max initial heights. In the general approach
                      ! we divide by (ncirc-1) which equals to zero if ncirc
                      ! is one. Therefore a special case was defined.
                      ave_tree_height(ncirc) = (height_init_min(ivm) + &
                           height_init_max(ivm))/2
                   
                   ELSE

                      DO icir = 1,ncirc

                         ! Calculate the height range based on the prescribed 
                         ! min/max initial heights. Use the general approach.
                         ave_tree_height(icir) = height_init_min(ivm) + &
                              (icir-1) * (height_init_max(ivm) - &
                              height_init_min(ivm))/(ncirc-1)

                      ENDDO

                   ENDIF !ncirc.EQ.1

                   ! Allocation factors
                   ! Sapwood to root ratio
                   ! Following Magnani et al. 2000 "In order to decreases hydraulic 
                   ! resistance, the investment of carbon in fine roots or sapwood 
                   ! yields to the plant very different returns, both because of 
                   ! different hydraulic conductivities and because of the strong 
                   ! impact of plant height on shoot resistance. On the other hand, 
                   ! fine roots and sapwood have markedly different longevities and 
                   ! the cost of production, discounted for turnover, will differ 
                   ! accordingly. Optimal growth under hydraulic constraints requires 
                   ! that the ratio of marginal hydraulic returns to marginal annual 
                   ! cost for carbon investment in either roots or sapwood be the 
                   ! same (Bloom, Chapin & Mooney 1985; Case & Fair 1989). This
                   ! is formalized in equation (13) and further derived to obtain 
                   ! equation (17) in Magnani et al 2000. The latter is implemented 
                   ! here.Pipe_density is given in gC/m-3, convert to kg/m-3. And 
                   ! apply equation (17) in Magnani et al 2000. Note that c0_alloc 
                   ! was calculated at the start of this routine. The calculation 
                   ! itself is done in function_library

                   ! Calculate leaf area to sapwood area
                   ! To be consistent with the hydraulic limitations and pipe theory,
                   ! k_latosa is calculated from equation (18) in Magnani et al.
                   ! To do so, total hydraulic resistance and tree height need to 
                   ! known. This poses a problem as the resistance depends on the leaf 
                   ! area and the leaf area on the resistance. There is no independent 
                   ! equation and equations 12 and 18 depend on each other and 
                   ! substitution would be circular. Hence prescribed k_latosa values 
                   ! were obtained from observational records and are given in 
                   ! mtc_parameters.f90. 

                   ! The relationship between height and k_latosa as reported in 
                   ! McDowell et al 2002 and Novick et al 2009 could be implemented 
                   ! to adjust k_latosa for the height of the stand. This did NOT 
                   ! result in a realistic model behavior 
                   ! k_latosa(ipts,ivm) = wstress_fac(ipts,ivm) * &
                   !    (k_latosa_max(ivm) - (latosa_height(ivm) * &
                   !    (SUM( nb_trees_i(:) * ave_tree_height(:) ) / &
                   !       SUM( nb_trees_i(:) ))))

                   ! Also k_latosa has been reported to be a function of CO2 
                   ! concentration (Atwell et al. 2003, Tree Physiology, 23:13-21 
                   ! and Pakati et al. 2000, Global Change Biology, 6:889-897). 
                   ! This effect is not accounted for in the current code

                   ! Finally, k_latosa is also reported to be a function of 
                   ! diameter (i.e. stand thinning, Simonin et al 2006, Tree 
                   ! Physiology, 26:493-503). Here the relationship with thinning was 
                   ! interpreted as a realtionship with light stress. Note that light 
                   ! stress cannot be calculated at this time in the model because 
                   ! there is no canopy (that's why we are in prescribe!) and
                   ! so there is no lightstress. lstress was therefore set to one 
                   ! (see above). We prefered to keep this redundancy in the code 
                   ! because it makes it clear that k_latosa is calculated in the 
                   ! same way in prescribe.f90 and growth_fun_all.f90
                   k_latosa(ipts,ivm) = (k_latosa_adapt(ipts,ivm) + &
                        (lstress_fac(ipts,ivm) * &
                        (k_latosa_max(ivm)-k_latosa_min(ivm))))

                   ! +++CHECK+++
                   ! Ideally waterstress and lightstress should both
                   ! affect k_latosa. One of the following approaches could
                   ! be used as a starting point.
                   !  k_latosa(ipts,ivm) = k_latosa_min(ivm) + &
                   !     (wstress_fac(ipts,ivm) * lstress_fac(ipts,ivm) * &
                   !     (k_latosa_max(ivm)-k_latosa_min(ivm)))
                   !  k_latosa(ipts,ivm) = wstress_fac(ipts,ivm) * (k_latosa_min(ivm) + &
                   !      (lstress_fac(ipts,ivm) * &
                   !      (k_latosa_max(ivm)-k_latosa_min(ivm))))
                   ! ++++++++++++

                   ! Calculate conversion coefficient for sapwood area to leaf 
                   ! area 
                   ! (1) The scaling parameter between leaf and sapwood mass 
                   ! is derived from LA_ind = k_latosa * SA_ind, where 
                   ! LA_ind = leaf area of an individual, SA_ind is the sapwood 
                   ! area of an individual and k_latosa a pipe-model parameter
                   ! (2) LA_ind = Cl * sla
                   ! (3) Cs = SA_ind * height * wooddensity * tree_ff
                   ! Substitute (2) and (3) in (1)
                   ! Cl = Cs * k1 / (wooddensity * sla * tree_ff * height)
                   ! Cl = Cs*KF/height, where KF is in (m)
                   ! KF is passed to the allocation routine and it is saved in the 
                   ! restart file.
                   KF(ipts,ivm) = k_latosa(ipts,ivm) / &
                        ( sla(ivm) * pipe_density(ivm) * tree_ff(ivm))

                   ! Initialize delta_KF to get the DO WHILE started
                   delta_KF = un
                   iloop=0
                   DO WHILE (delta_KF .GT. max_delta_KF)

                      ! If there is a WHILE loop, there always needs to be a check 
                      ! on the number of loops to make sure we don't get stuck in 
                      ! an infinite loop. This number is completely arbitrary.
                      iloop=iloop+1
                      IF(iloop > 1000)THEN

                         WRITE(numout,*) 'Taking too long to converge the '//&
                              'delta_KF loop in prescribe!'
                         WRITE(numout,*) 'iloop,delta_KF,max_delta_KF,ivm,ipts: ',&
                              iloop,delta_KF,max_delta_KF,ivm,ipts
                         CALL ipslerr_p (3,'stomate_prescribe',&
                              'Taking too long to converge the delta_KF','','')

                      ENDIF


                      ! Now we create the saplings for each class, based on the 
                      ! height
                      DO icir = 1,ncirc

                         ! The assumption we make is that we plant trees of 2 to 3 
                         ! years old rather than growing trees from seeds. The 
                         ! allometric relationship between height and diameter is 
                         ! derived from mature tree and likely unrealistic for 
                         ! saplings. The height of the saplings is prescribed and 
                         ! determines the reserves which are especially important 
                         ! for deciduous species which need to survive on their 
                         ! reserves for the first year (new phenology scheme requires 
                         ! annual mean values to get started). These are aboveground
                         ! values for dia_init and wood_init.
                         dia_init = ( ave_tree_height(icir) / pipe_tune2(ivm) ) ** &
                              ( 1. / pipe_tune3(ivm) )
                         wood_init = ( ave_tree_height(icir) * pi / 4. * &
                              (dia_init) ** 2. ) * pipe_density(ivm) * tree_ff(ivm)

                         ! Use the variables from the pipe model and the allometric
                         ! relationships to calculate the different biomass components
                         ! of the saplings in each diameter class.
                         CALL make_saplings(wood_init, bm_sapl, &
                              ave_tree_height(icir), icir, ivm, &
                              ipts, npts, KF, c0_alloc, plant_status, &
                              establish)  

                      ENDDO ! ncirc

                      ! Determine the biomass in each circumference class.
                      ! Calculations are based on the biomass in each sapling and 
                      ! the number of trees in each circumference class. Total
                      ! leaf biomass is needed for the light stress calculation
                      ! below.
                      DO icir=1,ncirc
                         circ_class_biomass(ipts,ivm,icir,:,:) = &
                              bm_sapl(ivm,icir,:,:)
                      ENDDO

                      ! The light stress should be calculated making use of Pgap so 
                      ! it accounts for LAI crown dimensions and tree distribution. 
                      ! However, this would be computationally expensive so we just 
                      ! use a first order estimate based on light attenuation model 
                      ! by Lambert-Beer. When LAI is low, a lot of light reaches the 
                      ! forest floor and so KF should increase to make use of the 
                      ! available light by growing leaves
                      lstress_fac = &
                           exp(-cc_to_lai(circ_class_biomass(ipts,ivm,:,ileaf,icarbon),&
                           circ_class_n(ipts,ivm,:),ivm))

                      ! Causing large differences between first and second prescribe
                      delta_KF = ABS (KF(ipts,ivm) - ((k_latosa_adapt(ipts,ivm) + &
                           (lstress_fac(ipts,ivm) * &
                           (k_latosa_max(ivm)-k_latosa_min(ivm))))) / &
                           ( sla(ivm) * tree_ff(ivm) * pipe_density(ivm) ))
                      KF(ipts,ivm) = ((k_latosa_adapt(ipts,ivm) + &
                           (lstress_fac(ipts,ivm) * &
                           (k_latosa_max(ivm)-k_latosa_min(ivm)))) / &
                           ( sla(ivm) * tree_ff(ivm) * pipe_density(ivm) ))

                      ! Debug
                      IF(printlev_loc>=4)THEN
                         WRITE(numout,*) 'prescribe delta_KF, ', delta_KF
                         WRITE(numout,*) 'prescribe lstress, ', lstress_fac
                      ENDIF
                      ! -

                   END DO ! DO WHILE delta_KF

                   ! The biomass of the saplings is known. Calculate the
                   ! quadratic mean diameter and the max number of trees
                   ! the stand can carry according to the self-thinning
                   ! relationship. Calculate the tree distribution by making
                   ! use of the prescribed number of trees
                   circ_class_n(ipts,ivm,:) = circ_class_dist(:) / &
                        SUM(circ_class_dist(:)) * nmaxtrees(ivm) * ha_to_m2

                   ! Calculate the quadratic mean diameter of the prescribed
                   ! stand.
                   qmd_init = &
                        wood_to_qmdia(circ_class_biomass(ipts,ivm,:,:,icarbon),&
                        circ_class_n(ipts,ivm,:),ivm)
 
                   ! Calculate the expected density under self-thinning.
                   ! unit is trees.ha-1
                   ind_init = Nmax(qmd_init*m_to_cm,ivm)

                   ! Take the lowest density. The reason for taking the lowest
                   ! is that the highest density could be up to 50 10E6 trees
                   ! per hectare. Given that our allometric rules are for 
                   ! mature trees, this then results in an LAI of ~980 which
                   ! makes the albedo routine crash (because of quality checks).
                   ! Because every individual tree hardly grows, self-thinning 
                   ! goes way to slow. For these reason we start with a more
                   ! reasonable number of trees per hectare and will use a
                   ! background mortality to make the number of trees decrease
                   IF (nmaxtrees(ivm) .GT. ind_init) THEN
                      
                      ! Recalculate stand density and diameter distribution
                      circ_class_n(ipts,ivm,:) = circ_class_dist(:) / &
                           SUM(circ_class_dist(:)) * ind_init * ha_to_m2

                   ENDIF

                   ! Debug
                   IF (printlev_loc>=4) THEN
                      DO icir=1,ncirc
                         WRITE(numout,*)'icir, circ_class_n, ', icir, &
                              circ_class_n(ipts,ivm,icir)
                         WRITE(numout,*)'Initial biomass distribution - carbon'
                         WRITE(numout,*) circ_class_biomass(ipts,ivm,icir,:,icarbon)
                         WRITE(numout,*) circ_class_biomass(ipts,ivm,icir,:,initrogen)
                      ENDDO
                      WRITE(numout,*)' Total number of saplings', &
                           SUM(circ_class_n(ipts,ivm,:))
                   END IF
                   !-

                ELSEIF (recruite) THEN

                   !! Calculate the number of recruits
                   ! Recruitment is based on the light stress factor [0 1] computed
                   ! above. It makes use of the functional response of recruitment
                   ! to light described by Ruger et al (2009, J. of Ecol.,
                   ! doi: 10.1111/j.1365-2745.2009.01552.x) in the 50-ha plot of Barro
                   ! Colorado Island (BCI) in Panama: 
                   ! Log10(Nrecruits)= A + B * ( Log10(lstress_fac) - MU )
                   !
                   ! Where Nrecruits is the number of recruits for an area of 25 m2.
                   ! The parameter A is the intercept (mean log10 recruits expected), 
                   ! B the slope (functional response), and MU=Log10(0.02)=-1.7 
                   ! Here the recruitment response to light can be negative (B<0),
                   ! decelerating (0<B<1), accelerating (B>1) or linear (B=1). 
                   ! MU is needed here to express the fraction of light between 0 and 1
                   ! centred on mean light 2% at BCI. The linearized (log-log) power
                   ! model is implemented here for each PFT following the original setup
                   ! of Ruger et al 2009 to ensure realistic values. IT COULD EASILY BE
                   ! SIMPLIFIED. The predicted number of recruits is for an area of
                   ! 25 m2 so we have to compute the antilogarithm and divide by 25 to
                   ! get the estimate by 1 m2 which is the unit used in ORCHIDEE.
                   !
                   ! Add min_stomate (a very small number) to lstress_fac to avoid numerical
                   ! issues with LOG10(zero) being undefined.
                   IF (recruitment_alpha(ivm).LT.min_stomate .AND. &
                        recruitment_beta(ivm).LT.min_stomate) THEN
                      
                      ! Sanity check. If the users sets both values to zero
                      ! new_ind is set to zero. The simulation should be 
                      ! identical to a simulation without recruitment.
                      new_ind = zero
                      
                   ELSE

                      ! Calculate the number of recruits
                      new_ind = ( 10**( recruitment_alpha(ivm) + &
                           recruitment_beta(ivm) * &
                           ( LOG10(lstress_fac(ipts,ivm)+min_stomate) - &
                           LOG10(0.02) ) ) )/25

                   ENDIF

                   ! Update the number of individuals
                   tmp_ind = SUM(circ_class_n(ipts,ivm,:))
                   old_ind = tmp_ind
                   tmp_ind = tmp_ind + new_ind

                   ! Debug
                   IF(printlev_loc>=4)THEN
                      WRITE(numout,*) 'PFT, ',ivm
                      WRITE(numout,*) 'canopy cover (LAI), ',&
                           cc_to_lai(circ_class_biomass(ipts,ivm,:,ileaf,icarbon),&
                           circ_class_n(ipts,ivm,:),ivm) 
                      WRITE(numout,*) 'used canopy_gap (%) is, ', lstress_fac(ipts,ivm)*100 
                      WRITE(numout,*) 'Original ind is, ', (tmp_ind - new_ind)*m2_to_ha
                      WRITE(numout,*) 'new_ind is, ', new_ind*m2_to_ha
                      WRITE(numout,*) 'ind+new_ind is, ', tmp_ind*m2_to_ha
                      qmd_init = &
                        wood_to_qmdia(circ_class_biomass(ipts,ivm,:,:,icarbon),&
                        circ_class_n(ipts,ivm,:),ivm)
                      WRITE(numout,*) 'Dg (m) ', qmd_init
                      ind_init = Nmax(qmd_init*m_to_cm,ivm)
                      WRITE(numout,*) 'Nmax, ',ind_init
                   ENDIF
                   !-

                   !! Calculate the dimensions of the recruits    
                   ! The height of the saplings is prescribed and determines the reserves
                   ! which are especially important for deciduous species, which need to
                   ! survive on their reserves for the first couple of months to a whole
                   ! year because the phenology scheme requires annual mean values to get
                   ! started. Calculate sapling diameter and biomass for prescribed sapling
                   ! height 
                   dia_init = ( recruitment_height(ivm) / pipe_tune2(ivm) ) ** &
                        ( 1. / pipe_tune3(ivm) )
                   wood_init = (recruitment_height(ivm) * pi / 4. * (dia_init) ** 2. ) * &
                        pipe_density(ivm) * tree_ff(ivm)

                   ! Use the variables from the pipe model and the allometric
                   ! relationships to calculate the different biomass components
                   ! of the saplings in each diameter class.
                   CALL make_saplings(wood_init, bm_sapl, recruitment_height(ivm), &
                        1, ivm, ipts, npts, KF, c0_alloc, plant_status, establish)

                   ! Debug
                   IF (printlev_loc>=4) THEN
                      WRITE(numout,*)'Prescribed recruitment height (m): ',recruitment_height(ivm)
                      WRITE(numout,*)'Recruitment diameter (m) for prescribed height: ', dia_init
                      WRITE(numout,*)'Wood_init recruitment: ',wood_init
                      WRITE(numout,*)'ind_init ',ind_init
                      WRITE(numout,*)'bm_sapl after calling make_saplings: ',bm_sapl(ivm,1,:,:)
                   ENDIF
                   !-

                   ! Update the number of individuals in the first size class. All
                   ! recruitment occurs in the circ_class with the smallest diameter
                   old_circ_class_n(ipts,ivm,:) = circ_class_n(ipts,ivm,:)
                   circ_class_n(ipts,ivm,1) = circ_class_n(ipts,ivm,1) + new_ind                        

                   !! Determine the biomass in the first circumference class.
                   ! This is a dillution approach were an average tree is made by making use
                   ! of the biomass in the available trees and the biomass in the recruits.
                   ! This is a simple mean weighted by the number of trees. The model needs
                   ! the biomass in an individual tree (gC tree-1)
                   DO iele = 1,nelements
                      old_circ_class_biomass(ipts,ivm,:,:,iele) = &
                           circ_class_biomass(ipts,ivm,:,:,iele) 
                      circ_class_biomass(ipts,ivm,1,:,iele) = &
                           (circ_class_biomass(ipts,ivm,1,:,iele) * &
                           old_circ_class_n(ipts,ivm,1) + &
                           bm_sapl(ivm,1,:,iele) * new_ind ) / &
                           circ_class_n(ipts,ivm,1)
                   ENDDO

                   ! Debug
                   IF (printlev_loc>=4) THEN
                      WRITE(numout,*) "Canopy gap (%)", lstress_fac(ipts,ivm)*100
                      WRITE(numout,*) "Original density (N/ha): ",&
                           old_circ_class_n(ipts,ivm,:)*m2_to_ha
                      WRITE(numout,*) "New density (N/ha): ",circ_class_n(ipts,ivm,:)*m2_to_ha
                      WRITE(numout,*) "Recruited saplings per ha in first size class ", &
                           new_ind * m2_to_ha
                      WRITE(numout,*) "Original biomass per individual", &
                           SUM(old_circ_class_biomass(ipts,ivm,:,:,icarbon),2),&
                           SUM(old_circ_class_biomass(ipts,ivm,:,:,initrogen),2)
                      WRITE(numout,*) "New biomass per individual", &
                           SUM( circ_class_biomass(ipts,ivm,:,:,icarbon),2 ),&
                           SUM( circ_class_biomass(ipts,ivm,:,:,initrogen),2 )
                      WRITE(numout,*) "Biomass of new saplings gC/sapling", &
                           bm_sapl(ivm,1,:,icarbon)
                       WRITE(numout,*) "Biomass of new saplings gN/sapling", &
                           bm_sapl(ivm,1,:,initrogen)
                      WRITE(numout,*) "KF ", KF(ipts,ivm)
                   ENDIF
                   !-

                ENDIF ! end prescribe/recruitment block

                IF (establish) THEN

                   ! Set leaf age classes, all leaves are current year leaves
                   leaf_frac(ipts,ivm,:) = zero
                   leaf_frac(ipts,ivm,1) = un

                   ! Set time since last beginning of growing season but only
                   ! for the first day of the whole simulation. When the model
                   ! is initialized when_growthinit is set to undef. In subsequent
                   ! time steps it should have a value. For trees without phenology
                   ! the growing season starts at the moment the PFT is prescribed
                   IF (when_growthinit(ipts,ivm) .EQ. undef) THEN
                      when_growthinit(ipts,ivm) = 200
                   ENDIF

                ENDIF

                ! The carbon and nitrogen to build the saplings is taken from the 
                ! atmosphere, keep track of amount to calculate the C-balance 
                ! closure
                IF (establish) THEN

                   ! The whole biomass of this PFT was taken from the
                   ! atmosphere
                   atm_to_bm(ipts,ivm,:) = atm_to_bm(ipts,ivm,:) + &
                        (SUM(cc_to_biomass(npts, ivm, &
                        circ_class_biomass(ipts,ivm,:,:,:), &
                        circ_class_n(ipts,ivm,:)),1) / dt )

                ELSEIF (recruite) THEN

                   ! Only the increase in biomass of this PFT was taken
                   ! from the atmosphere
                   atm_to_bm(ipts,ivm,:) = atm_to_bm(ipts,ivm,:) + &
                        (SUM(cc_to_biomass(npts, ivm, &
                        circ_class_biomass(ipts,ivm,:,:,:), &
                        circ_class_n(ipts,ivm,:)) - &
                        old_biomass(ipts,ivm,:,:),1)  / dt )
                   
                ENDIF

                ! Check whether the order was preserved. We only want to
                ! preserve the order for the carbon biomass. Nitrogen follows
                ! carbon. We expect that the biomass of an individual tree 
                ! increases with an increasing circ class. This is probably 
                ! not important for the correct functioning of the model. So,
                ! if this turns out to be computationally expensive it is 
                ! worth trying without. We try to preserve the order as
                ! an additional mean to control the quality of the simulations.
                ! A strict order also helps to interpret the output. Hence, 
                ! if the order was not preserved we will sort the biomasses. 
                ! Note that this subroutine first checks whether the order 
                ! was preseverd.
                circ_class_biomass_new = circ_class_biomass(ipts,ivm,:,:,:)
                circ_class_n_new = circ_class_n(ipts,ivm,:)
                CALL sort_circ_class_biomass(circ_class_biomass_new, &
                     circ_class_n_new)
                circ_class_biomass(ipts,ivm,:,:,:) = circ_class_biomass_new
                circ_class_n(ipts,ivm,:) = circ_class_n_new

             ENDIF ! tree(ivm)

             !! 2.3.2 Initialize grassy PFTs
             !  Use veget_cov_max to check whether the PFT is present. If the PFT is 
             !  present but it has no biomass, prescribe its biomass (gC m-{2}). 
             !  It is assumed that at day 1 grasses have all their biomass in the 
             !  reserve pool. The criteria exclude crops. Crops are no longer 
             !  prescribed but planted the day that begin_leaves is true.
             IF (establish) THEN

                IF ( ( .NOT. is_tree(ivm) ) .AND. &
                     ( natural(ivm) ) .AND. &
                     ( veget_cov_max(ipts,ivm) .GT. min_stomate ) .AND. &
                     ( SUM(circ_class_biomass(ipts,ivm,1,:,icarbon) ) .LE. min_stomate ) ) THEN

                   ! Debug
                   IF(printlev_loc>=4)THEN
                      WRITE(numout,*) 'We will prescribe a new grass  '//&
                           'vegetation, the old one died'
                   ENDIF
                   ! -

                   ! For grasses we assume that an individual grass is 1 m2 of grass. 
                   ! This is set in nmaxtrees in pft_parameters.f90. It could be set 
                   ! to another value but with the current code this should not have 
                   ! any meaning. The grassland does not necessarily covers the whole 
                   ! 1 m2 so adjust for the canopy cover
                   tmp_ind = nmaxtrees(ivm) * ha_to_m2 * canopy_cover(ivm)

                   !+++CHECK+++
                   ! We do not deal with circumference classes for grasses
                   ! and crops, but we want to keep the arrays the same as for the trees 
                   ! so we put the young grass information into the first circumference 
                   ! class. Calculate the sapwood to leaf mass in a similar way as has 
                   ! been done for trees. For trees this approach had been justified by 
                   ! observations. For grasses such justification is not supported by 
                   ! observations but we didn't try to find it. Needs more work by 
                   ! someone interested in grasses. There might be a more elegant
                   ! solution making use of a well observed parameter. 
                   k_latosa(ipts,ivm) = (k_latosa_adapt(ipts,ivm) + &
                        (lstress_fac(ipts,ivm) * &
                        (k_latosa_max(ivm)-k_latosa_min(ivm))))

                   ! The mass of the structural carbon relates to the mass of the leaves 
                   ! through a prescribed parameter ::k_latosa
                   KF(ipts,ivm) = k_latosa(ipts,ivm)
                   !+++++++++++

                   ! Calculate leaf to root area    
                   LF(ipts,ivm) = c0_alloc(ivm) * KF(ipts,ivm)

                   ! Debug
                   IF(printlev_loc>=4.AND. test_pft == ivm)THEN
                      WRITE(numout,*) 'KF, ', k_latosa(ipts,ivm), KF(ipts,ivm)
                      WRITE(numout,*) 'LF, c0_alloc, ', c0_alloc(ivm) * KF(ipts,ivm), &
                           c0_alloc(ivm)
                   ENDIF
                   !-

                   ! initialize everything to make sure there are not random values 
                   ! floating around for ncirc = 1
                   bm_sapl(ivm,1,:,:) = val_exp

                   ! Similar as for trees, the initial height of the vegetation was 
                   ! defined 
                   bm_sapl(ivm,1,ileaf,icarbon) = height_init_min(ivm) / &
                        lai_to_height(ivm) / sla(ivm)

                   ! Use allometric relationships to define the root mass based on 
                   ! leaf mass. Some 'sapwood mass' is needed to store the reserves. 
                   ! An arbitrairy fraction of 5% was used 
                   bm_sapl(ivm,1,iroot,icarbon) = bm_sapl(ivm,1,ileaf,icarbon) / &
                        LF(ipts,ivm)
                   bm_sapl(ivm,1,isapabove,icarbon) = bm_sapl(ivm,1,ileaf,icarbon) / &
                        KF(ipts,ivm)

                   ! Some of the biomass components that exist for trees are undefined 
                   ! for grasses
                   bm_sapl(ivm,1,isapbelow,icarbon) = zero
                   bm_sapl(ivm,1,iheartabove,icarbon) = zero
                   bm_sapl(ivm,1,iheartbelow,icarbon) = zero
                   bm_sapl(ivm,1,ifruit,icarbon) = zero
                   bm_sapl(ivm,1,icarbres,icarbon) = zero

                   ! Pools that are defined in the same way for trees and grasses
                   bm_sapl(ivm,1,ilabile,icarbon) = labile_to_total * &
                        (bm_sapl(ivm,1,ileaf,icarbon) + &
                        fcn_root(ivm) * bm_sapl(ivm,1,iroot,icarbon) + fcn_wood(ivm) * &
                        (bm_sapl(ivm,1,isapabove,icarbon) + &
                        bm_sapl(ivm,1,isapbelow,icarbon) + &
                        bm_sapl(ivm,1,icarbres,icarbon)))

                   ! Allocate the nitrogen
                   cn_leaf=cn_leaf_init(ivm) 
                   cn_wood=cn_leaf/fcn_wood(ivm) 
                   cn_root=cn_leaf/fcn_root(ivm) 

                   !+++CHECK+++
                   ! See comments at a similmar block of code for the
                   ! tree saplings
                   ! Use the C/N ratio to calculate the N content for
                   ! all the biomass components.
                   bm_sapl(ivm,1,:,initrogen) = &
                        bm_sapl(ivm,1,:,icarbon) / cn_root

                   ! Overwrite the N content for the leaves and wood
                   ! components. Note that only sapabove is defined the
                   ! other wood components are zero
                   bm_sapl(ivm,1,ileaf,initrogen) = &
                        bm_sapl(ivm,1,ileaf,icarbon) / cn_leaf
                   bm_sapl(ivm,1,isapabove,initrogen) = &
                        bm_sapl(ivm,1,isapabove,icarbon) / cn_wood
                   !++++++++++++

                   ! Avoid deciduous PFTs to have leaves out at establishment
                   ! Whether the saplings have leaves or don't have leaves the first 
                   ! year doesn't really matter. Either the approach is correct in the 
                   ! northern hemisphere or in the southern hemisphere. Note
                   ! that the resource limitation approach starts with the sapling having 
                   ! leaves. Anyhow, a spin-up is recommended to avoid issues with the 
                   ! initial conditions
                   IF ( pheno_type(ivm) .NE. 1 ) THEN

                      ! Not evergreen. Deciduous PFTs now need to survive half a year 
                      ! before bud burst. To ensure survival there are several options: 
                      ! (a) either the height of the initial vegetation is increased 
                      ! (this results in more reserves) or (b) the reserves could be
                      ! increased. The second option may result in result in numerical 
                      ! issues further down the code as the optimal reserve level is 
                      ! calculated from the other biomass pools
                      bm_sapl(ivm,1,icarbres,:) = bm_sapl(ivm,1,icarbres,:) + &
                           bm_sapl(ivm,1,ileaf,:) + &
                           bm_sapl(ivm,1,iroot,:) + &
                           bm_sapl(ivm,1,isapabove,:)
                      bm_sapl(ivm,1,ileaf,:) = zero
                      bm_sapl(ivm,1,iroot,:) = zero
                      bm_sapl(ivm,1,isapabove,:) = zero

                      ! When there are no leaves, the crop/grass is dormant
                      plant_status(ipts,ivm) = idormant

                   ELSE

                      ! Initilize carbohydrate reserves for evergreen PFTs
                      bm_sapl(ivm,1,icarbres,:) = zero 

                      ! Evergreen plants always have a canopy
                      plant_status(ipts,ivm) = icanopy

                   ENDIF

                   ! Debug
                   IF (printlev_loc>=4) THEN
                      DO iele=1,nelements
                         WRITE(numout,*) ' young grass biomass (gC):',ivm,ipts
                         WRITE(numout,*) '  bm_sapl(:,1,ileaf,:,) ',&
                              bm_sapl(ivm,1,ileaf,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,ispabove,:) ',&
                              bm_sapl(ivm,1,isapabove,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,isapbelow,:) ',&
                              bm_sapl(ivm,1,isapbelow,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,iheartabove,:) ',&
                              bm_sapl(ivm,1,iheartabove,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,iheartbelow,:) ',&
                              bm_sapl(ivm,1,iheartbelow,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,iroot,:) ',&
                              bm_sapl(ivm,1,iroot,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,ifruit,:)', &
                              bm_sapl(ivm,1,ifruit,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,icarbres,:)', &
                              bm_sapl(ivm,1,icarbres,iele)
                         WRITE(numout,*) '  bm_sapl(:,1,ilabile,:)', &
                              bm_sapl(ivm,1,ilabile,iele)
                      ENDDO
                   ENDIF
                   ! -

                   ! Synchronize biomass and circ_class_biomass (gC tree-1). This 
                   ! allows to more easily check the mass balance closure
                   circ_class_biomass(ipts,ivm,1,:,:) = bm_sapl(ivm,1,:,:)
                   circ_class_n(ipts,ivm,1) = tmp_ind

                   ! Set leaf age classes -> all leaves will be current year leaves
                   leaf_frac(ipts,ivm,:) = zero
                   leaf_frac(ipts,ivm,1) = un

                   ! Set time since last beginning of growing season but only
                   ! for the first day of the whole simulation. When the model
                   ! is initialized when_growthinit is set to undef. In subsequent
                   ! time steps it should have a value.
                   IF (when_growthinit(ipts,ivm) .EQ. undef) THEN
                      when_growthinit(ipts,ivm) = 200
                   ENDIF

                   ! The carbon and nitrogen biomass to build the saplings is taken 
                   ! from the atmosphere, keep track of amount to calculate the mass 
                   ! balance closure
                   DO iele = 1,nelements
                      atm_to_bm(ipts,ivm,iele) = atm_to_bm(ipts,ivm,iele) + &
                           ((SUM(circ_class_biomass(ipts,ivm,1,:,iele))*&
                           circ_class_n(ipts,ivm,1)) / dt)
                   ENDDO

                   ! Debug
                   IF (printlev_loc>=4) THEN
                      DO iele=1,nelements
                         WRITE(numout,*) ' root to sapwood tradeoff (LF) : ', c0_alloc(ivm)
                         WRITE(numout,*) ' grass sapling biomass: ',bm_sapl(ivm,1,:,iele)
                      ENDDO
                   ENDIF
                   ! -

                ELSEIF (.NOT. natural(ivm)) THEN

                   ! Initialize croplands - else leaves_begin will never become true
                   ! Set time since last beginning of growing season but only
                   ! for the first day of the whole simulation. When the model
                   ! is initialized when_growthinit is set to undef. In subsequent
                   ! time steps it should have a value.
                   IF (when_growthinit(ipts,ivm) .EQ. undef) THEN
                      when_growthinit(ipts,ivm) = 200
                   ENDIF

                   ! Debug
                   IF (printlev_loc>=4) WRITE(numout,*) 'Initialize crops',ivm
                   !-

                ENDIF ! .NOT. tree(ivm)

             ENDIF ! establish (for .NOT. is_tree(ivm)) 

             !! 2.3.3 Declare PFT present 
             !! Now that the PFT has biomass it should be declared 'present'
             !! everywhere in that grid box. Assign some additional properties
             IF (establish) THEN
                PFTpresent(ipts,ivm) = .TRUE.
                everywhere(ipts,ivm) = un
                age(ipts,ivm) = zero
                npp_longterm(ipts,ivm) = npp_longterm_init
                lm_lastyearmax(ipts,ivm) = zero
             ENDIF

          ENDIF ! establish or recruite

       ENDDO ! loop over pixels

    ENDDO ! loop over PFTs

 !! 3. Check numerical consistency of this routine

    IF (err_act.GT.1) THEN

       ! 3.1 Check surface area
       CALL check_surface_area("stomate_prescribe", npts, veget_cov_max_begin, &
            veget_cov_max,'pft')

       ! 3.2 Mass balance closure 
       ! 3.2.1 Calculate final biomass
       pool_end(:,:,:) = zero 
       DO ipar = 1,nparts
          DO iele = 1,nelements
             DO icir = 1,ncirc
                pool_end(:,:,iele) = pool_end(:,:,iele) + &
                     (circ_class_biomass(:,:,icir,ipar,iele) * &
                     circ_class_n(:,:,icir) * veget_cov_max(:,:))
             ENDDO
          ENDDO
       ENDDO

       ! 3.2.2 Calculate mass balance
       ! Common processes
       DO iele=1,nelements
          check_intern(:,:,iatm2land,iele) = check_intern(:,:,iatm2land,iele) + &
               atm_to_bm(:,:,iele) * veget_cov_max(:,:) * dt
          check_intern(:,:,ipoolchange,iele) = -un * (pool_end(:,:,iele) - &
               pool_start(:,:,iele)) 
       ENDDO

       closure_intern(:,:,:) = zero
       DO imbc = 1,nmbcomp
          DO iele=1,nelements
             ! Debug
             IF (printlev_loc>=3) THEN              
                IF(iele .EQ. 1) WRITE(numout,"(9999(G12.5,:,','))") &
                  'imbc, test_pft, check_intern', test_grid , imbc, &
                  test_pft, check_intern(test_grid,test_pft,imbc,iele)
                ENDIF
             !-
             closure_intern(:,:,iele) = closure_intern(:,:,iele) + &
                  check_intern(:,:,imbc,iele)
          ENDDO
       ENDDO

       ! 3.3 Check mass balance closure
       CALL check_mass_balance("stomate_prescribe", closure_intern, npts, &
            pool_end, pool_start, veget_cov_max, 'pft')
      
    ENDIF ! err_act.GT.1

    IF(printlev>=3) WRITE(numout,*) 'Leaving stomate_prescribe.f90'

    firstcall_prescribe = .FALSE.
     
  END SUBROUTINE prescribe



!! ================================================================================================================================
!! SUBROUTINE   : make_sapling
!!
!>\BRIEF Given the dimensions and the allocation factors, calculate the biomass of a sapling        
!!
!! DESCRIPTION (functional, design, flags):
!!
!! RECENT CHANGE(S): None
!!
!! MAIN OUTPUT VARIABLES(S): ::bm_sapl, ::KF
!!
!! REFERENCES   :
!!
!! FLOWCHART    : None
!! \n
!_ ================================================================================================================================

   SUBROUTINE make_saplings(wood_init, bm_sapl, tree_height, icir, &
                           ivm, ipts, npts, KF, c0_alloc, plant_status, &
                           establish)

    !! 0. Parameters and variables declaration

    !! 0.1 Input variables
    REAL(r_std), INTENT(in)                            :: wood_init
    REAL(r_std), INTENT(in)                            :: tree_height        !! Tree height (m)
    INTEGER(i_std), INTENT(in)                         :: ivm, icir, ipts    !! index (unitless)
    INTEGER(i_std), INTENT(in)                         :: npts               !! Domain size (unitless)
    REAL(r_std), DIMENSION(:), INTENT(in)              :: c0_alloc           !! Root to sapwood tradeoff parameter
    LOGICAL, INTENT(in)                                :: establish          !! yes: establish a new young vegetation. 
                                                                             !! No: add saplings under an existing vegetation

    !! 0.2 Output variables
    
    !! 0.3 Modified variables
    REAL(r_std), DIMENSION(:,:,:,:),INTENT(inout)      :: bm_sapl            !! Sapling biomass for the functional 
    REAL(r_std), DIMENSION(:,:), INTENT(inout)         :: KF                 !! Scaling factor to convert sapwood mass
                                                                             !! into leaf mass (m) - this variable is 
                                                                             !! passed to other routines
    REAL, DIMENSION(:,:), INTENT(inout)                :: plant_status       !! Growth and phenological status of the plant 
                                                                             !! Different stati defined in constants
    !! 0.4  Local variables
    INTEGER(i_std)                                    :: iele                !! index (unitless) 
    REAL(r_std)                                       :: cn_leaf,cn_root     !! CN ratio of leaves and roots (gC/gN)
    REAL(r_std)                                       :: cn_wood             !! CN ratio of wood pool (gC/gN)        
   


!_ ================================================================================================================================

      ! The woody biomass is contained in four components. Thus, 
      ! wood_init = isapabove + isapbelow + iheartabove + iheartbelow. 
      ! Given that isapbelow = isapbelow and iheartabove = 
      ! iheartbelow =  bm_sapl_heartabove*isapabove. If 
      ! bm_sapl_heartbelow = bm_sapl_heartabove = 0.2, then 
      ! isapabove = wood_init/2.4
      bm_sapl(ivm,icir,isapabove,icarbon) = wood_init / &
           (2. + bm_sapl_heartabove + bm_sapl_heartbelow) 
      bm_sapl(ivm,icir,isapbelow,icarbon) = bm_sapl(ivm,icir,isapabove,icarbon)
      bm_sapl(ivm,icir,iheartabove,icarbon) =  bm_sapl_heartabove * &
           bm_sapl(ivm,icir,isapabove,icarbon)
      bm_sapl(ivm,icir,iheartbelow,icarbon) =  bm_sapl_heartbelow * &
           bm_sapl(ivm,icir,isapbelow,icarbon)          

      ! Use the allometric relationships to calculate initial leaf 
      ! and root mass. Note that wstress should be accounted for
      ! through c0_alloc. There was an inconsistency in the
      ! original calculation (OCN) - most pools were in gN but 
      ! leaves were in gC. A correction is proposed. Given that 
      ! icarbes was just set to zero the equation for ilabile is 
      ! a bit overkill and icarbes could be omitted.
      bm_sapl(ivm,icir,ileaf,icarbon) = ( bm_sapl(ivm,icir,isapabove,icarbon) + &
           bm_sapl(ivm,icir,isapbelow,icarbon) ) * KF(ipts,ivm) /  tree_height 
      bm_sapl(ivm,icir,iroot,icarbon) = bm_sapl(ivm,icir,ileaf,icarbon) / &
           ( KF(ipts,ivm) * c0_alloc(ivm) )
      bm_sapl(ivm,icir,icarbres,icarbon)=zero
      bm_sapl(ivm,icir,ifruit,icarbon) = zero
      bm_sapl(ivm,icir,ilabile,icarbon) =  labile_to_total * &
           (bm_sapl(ivm,icir,ileaf,icarbon)  + &
           fcn_root(ivm) * bm_sapl(ivm,icir,iroot,icarbon) + &
           fcn_wood(ivm) * (bm_sapl(ivm,icir,isapabove,icarbon) + &
           bm_sapl(ivm,icir,isapbelow,icarbon) + &
           bm_sapl(ivm,icir,icarbres,icarbon)))      

      ! Debug
      IF (printlev_loc>=4) THEN 
         WRITE(numout,*) ' +++++ CHECK INSIDE make_sapling ++++ '
         WRITE(numout,*) 'Circumference class: ',icir,' PFT type: ',ivm
         WRITE(numout,*) ' root to sapwood tradeoff p :', c0_alloc(ivm)
         WRITE(numout,*) ' sapling height, sapling diameter, wood_init, ', &
              tree_height , ( tree_height/pipe_tune2(ivm) ) ** &
              ( 1. / pipe_tune3(ivm) ), wood_init
         WRITE(numout,*) 'pipe_density, ',pipe_density(ivm)
      ENDIF
      ! -

      ! Allocate the nitrogen
      cn_leaf=cn_leaf_init(ivm)
      cn_wood=cn_leaf/fcn_wood(ivm)
      cn_root=cn_leaf/fcn_root(ivm)

      ! Use the C/N ratio to calculate the N content for
      ! all the biomass components.
      bm_sapl(ivm,icir,:,initrogen) = &
           bm_sapl(ivm,icir,:,icarbon) / cn_root

      ! Overwrite the N content for the leaves and wood
      ! components.
      bm_sapl(ivm,icir,ileaf,initrogen) = &
           bm_sapl(ivm,icir,ileaf,icarbon) / cn_leaf
      bm_sapl(ivm,icir,isapabove,initrogen) = &
           bm_sapl(ivm,icir,isapabove,icarbon) / cn_wood
      bm_sapl(ivm,icir,isapbelow,initrogen) = &
           bm_sapl(ivm,icir,isapbelow,icarbon) / cn_wood
      bm_sapl(ivm,icir,iheartabove,initrogen) = &
           bm_sapl(ivm,icir,iheartabove,icarbon) / cn_wood
      bm_sapl(ivm,icir,iheartbelow,initrogen) = &
           bm_sapl(ivm,icir,iheartbelow,icarbon) / cn_wood

      ! Avoid deciduous PFTs to have leaves out at establishment
      ! Whether the saplings have leaves or don't have leaves the
      ! first year doesn't really matter. Either the approach is
      ! correct in the northern hemisphere or in the southern
      ! hemisphere. Anyhow, a spin-up is needed to avoid issues
      ! with the initial conditions
      IF ( pheno_type(ivm) .NE. 1 ) THEN
         
         ! Not evergreen. Deciduous PFTs now need to survive an extra
         ! year before bud burst. To ensure survival there are several
         ! options: (a) either the height of the initial vegetation is
         ! increased (this results in more reserves) or (b) the reserves
         ! could be increased. The second option may result in numerical
         ! issues further down the code as the optimal reserve level is
         ! calculated from the other biomass pools. Also some initial
         ! tests showed that higher reserves simply resulted in more
         ! respiration.
         ! Tip: use taller trees to start with if they die between
         ! prescribe and leaf onset
         bm_sapl(ivm,icir,icarbres,:) = (bm_sapl(ivm,icir,icarbres,:) + &
              bm_sapl(ivm,icir,ileaf,:) + bm_sapl(ivm,icir,iroot,:))
         bm_sapl(ivm,icir,ileaf,:) = zero
         bm_sapl(ivm,icir,iroot,:) = zero
      
         ! When deciduous trees have no leaves they are dormant
         ! If the code is used for recruitment use the actual 
         ! plant_status of the overstorey trees for the saplings
         IF (establish) THEN
            plant_status(ipts,ivm) = idormant
         ENDIF
         
      ELSE
         
         ! Initilize carbohydrate reserves for evergreen PFTs
         bm_sapl(ivm,icir,icarbres,:) = zero

         ! Evergreen trees always have a canopy. If the code
         ! is used for recruitment use the actual plant_status 
         ! of the overstorey trees for the saplings
         IF (establish) THEN
            plant_status(ipts,ivm) = icanopy
         ENDIF
    
      ENDIF

      ! Debug
      IF (printlev_loc>=4) THEN
         DO iele=1,nelements
            WRITE(numout,*) ' sapling biomass (gC):',icir,ivm,ipts
            WRITE(numout,*) '  bm_sapl(:,:,ileaf,:,) ',&
                 bm_sapl(ivm,icir,ileaf,iele)
            WRITE(numout,*) '  bm_sapl(:,:,ispabove,:) ',&
                 bm_sapl(ivm,icir,isapabove,iele)
            WRITE(numout,*) '  bm_sapl(:,:,isapbelow,:) ',&
                 bm_sapl(ivm,icir,isapbelow,iele)
            WRITE(numout,*) '  bm_sapl(:,:,iheartabove,:) ',&
                 bm_sapl(ivm,icir,iheartabove,iele)
            WRITE(numout,*) '  bm_sapl(:,:,iheartbelow,:) ',&
                 bm_sapl(ivm,icir,iheartbelow,iele)
            WRITE(numout,*) '  bm_sapl(:,:,iroot,:) ',&
                 bm_sapl(ivm,icir,iroot,iele)
            WRITE(numout,*) '  bm_sapl(:,:,ifruit,:)', &
                 bm_sapl(ivm,icir,ifruit,iele)
            WRITE(numout,*) '  bm_sapl(:,:,icarbres,:)', &
                 bm_sapl(ivm,icir,icarbres,iele)
            WRITE(numout,*) '  bm_sapl(:,:,ilabile,:)', &
                 bm_sapl(ivm,icir,ilabile,iele)
         ENDDO
      ENDIF
      
   END SUBROUTINE make_saplings
  
END MODULE stomate_prescribe
